/**
 * 演示程序当前的 “注册/登录” 等操作，是基于 “本地存储” 完成的
 * 当您要参考这个演示程序进行相关 app 的开发时，
 * 请注意将相关方法调整成 “基于服务端Service” 的实现。
 **/
(function($, owner) {
	/**
	 * 用户登录
	 **/
	owner.login = function(loginInfo, callback) {
		callback = callback || $.noop;
		loginInfo = loginInfo || {};
		loginInfo.account = loginInfo.account || '';
		loginInfo.password = loginInfo.password || '';
		if (loginInfo.account.length < 5) {
			return callback('账号最短为 5 个字符');
		}
		if (loginInfo.password.length < 6) {
			return callback('密码最短为 6 个字符');
		}
		//edit by xiaofu
		mui.ajax('http://app.gougougou.com/index.php?module=User&action=CheckLogin', {
			data: {
				username: loginInfo.account,
				password: loginInfo.password
			},
			dataType: 'json', //服务器返回json格式数据
			type: 'post', //HTTP请求类型
			timeout: 10000, //超时时间设置为10秒；
			success: function(data) {
				//服务器返回响应，根据响应结果，分析是否登录成功；
				if (data.status == '4') {
					return owner.createState(data.userinfo, callback);
				} else {
					return callback(data.message);
				}
			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log(type);
			}
		});

	};

	owner.createState = function(userinfo, callback) {
		var state = owner.getState();
		state.id = userinfo.id;
		state.nickname = userinfo.nickname;
		state.img = userinfo.img;
		state.token = userinfo.token;
		owner.setState(state);
		return callback();
	};
	//edit by xiaofu
	/**
	 * 新用户注册
	 **/
	owner.reg = function(regInfo, callback) {
		callback = callback || $.noop;
		regInfo = regInfo || {};
		regInfo.login_id = regInfo.login_id || '';
		regInfo.nickname = regInfo.nickname || '';
		regInfo.password = regInfo.password || '';
		if (regInfo.login_id.length < 5) {
			return callback('用户名最短需要 5 个字符');
		}
		if (regInfo.password.length < 6) {
			return callback('密码最短需要 6 个字符');
		}
		if (!checkEmail(regInfo.email)) {
			return callback('邮箱地址不合法');
		}
		//edit by xiaofu
		mui.ajax('http://app.gougougou.com/index.php?module=User&action=Register', {
			data: {
				login_id: regInfo.login_id,
				nickname: regInfo.nickname,
				password: regInfo.password,
				email: regInfo.email
			},
			dataType: 'json', //服务器返回json格式数据
			type: 'post', //HTTP请求类型
			timeout: 10000, //超时时间设置为10秒；
			success: function(data) {
				//服务器返回响应，根据响应结果，分析是否登录成功；
				if (data.status == '1') {
					return callback();
				} else {
					return callback(data.message);
				}
			},
			error: function(xhr, type, errorThrown) {
				//异常处理；
				console.log(type);
			}
		});
		//edit by xiaofu
	};

	/**
	 * 获取当前状态
	 **/
	owner.getState = function() {
	//	var stateText = localStorage.getItem('$state') || "{}";
		var stateText = getItemFun('$state') || "{}";
		return JSON.parse(stateText);
	};

	/**
	 * 设置当前状态
	 **/
	owner.setState = function(state) {
		state = state || {};
		//localStorage.setItem('$state', JSON.stringify(state));
		setItemFun('$state', JSON.stringify(state));
		//var settings = owner.getSettings();
		//settings.gestures = '';
		//owner.setSettings(settings);
	};

	var checkEmail = function(email) {
		email = email || '';
		return (email.length > 3 && email.indexOf('@') > -1);
	};

	/**
	 * 找回密码
	 **/
	owner.forgetPassword = function(email, callback) {
		callback = callback || $.noop;
		if (!checkEmail(email)) {
			return callback('邮箱地址不合法');
		}
		return callback(null, '新的随机密码已经发送到您的邮箱，请查收邮件。');
	};

	/**
	 * 获取应用本地配置
	 **/
	owner.setSettings = function(settings) {
		settings = settings || {};
		//localStorage.setItem('$settings', JSON.stringify(settings));
		setItemFun('$settings', JSON.stringify(settings));	
	}

	/**
	 * 设置应用本地配置
	 **/
	owner.getSettings = function() {
		//var settingsText = localStorage.getItem('$settings') || "{}";
		var settingsText = getItemFun('$settings') || "{}";
		return JSON.parse(settingsText);
	}
}(mui, window.app = {}));